@@ -5,7 +5,7 @@ Utilities module for Vacancy Predictor
 from vacancy_predictor.utils.validators import DataValidator
 from vacancy_predictor.utils.file_handlers import FileHandler
 from vacancy_predictor.utils.atom_visualizer import AtomVisualizer3D
-from vacancy_predictor.utils.lammps_parser import *
+from vacancy_predictor.utils.lammps_parser import FeatureSelectorGUI
 
 from vacancy_predictor.utils.constants import *
 
